/**
 * @file
 * Attaches behaviors for the Selectize.js module.
 */

(function ($, Drupal, drupalSettings) {

  'use strict';

  /**
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches behavior to the page from defined settings for selectize to each specified element.
   */
  Drupal.behaviors.selectize = {
    attach: function (context) {
      if (typeof drupalSettings.selectize != 'undefined') {
        $.each(drupalSettings.selectize, function (index, value) {
          if (typeof value !== 'object') {
            value = JSON.parse(value);
          }
          var config = value;
          if (typeof config.field_type !== 'undefined' && config.field_type === 'entity_reference') {
            config = Drupal.behaviors.selectize.appendAutocompleteConfig(index, config);
          }
          var $el = $('#' + index);
          $el.selectize(config);
        });
      }
    },
    appendAutocompleteConfig: function (index, config) {
      var url = $('#' + index).data('selectize-autocomplete-path');
      config.persist = true;
      config.searchField = 'label';
      if (config.hideTermId) {
        config.valueField = config.searchField;
        config.labelField = config.searchField;
      }
      config.render = {
        option: function (item, escape) {
          // Removes the term id and parenthesis of the shown text.
          if (typeof item.label === 'undefined' && typeof item.text !== 'undefined') {
            item.label = item.text.replace(/\([\d]*\)/, '');
          }
          return '<div class="item" data-value="' + item.value + '">' + item.label + '</div>';
        },
        item: function (item, escape) {
          if (typeof item.label !== 'undefined' && typeof item.text === 'undefined') {
            item.text = item.label;
          }
          if (config.hideTermId === '1') {
            item.text = item.text.replace(/\([\d]*\)/, '').trim();
          }
          return '<div class="item" data-value="' + item.value + '">' + item.text + '</div>';
        }
      };
      config.load = function (query, callback) {
        if (!query.length) return callback();
        $.ajax({
          url: url,
          data: {
            q: query,
          }
        })
        .fail(function () {
          callback();
        })
        .done(function (response) {
          return callback(response);
        });
      };
      return config;
    }
  };

})(jQuery, Drupal, drupalSettings);
