<?php

namespace Drupal\selectize\Element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element\Select;
use Drupal\selectize\SelectizeElementTrait;

/**
 * Provides a selectized form element.
 *
 * @FormElement("selectize")
 */
class Selectize extends Select {

  use SelectizeElementTrait;

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $info = parent::getInfo();
    $class = get_class($this);

    // Apply default form element properties.
    $info['#settings'] = self::settings();
    array_unshift($info['#process'], [$class, 'processSelectize']);
    array_unshift($info['#pre_render'], [$class, 'preRenderSelectize']);

    return $info;
  }

  /**
   * {@inheritdoc}
   */
  public static function processSelectize(&$element, FormStateInterface $form_state, &$complete_form) {
    if (isset($element['#settings'])) {
      if (isset($element['#settings']['sortField']) && isset($element['#settings']['sortDirection'])) {
        $element['#settings']['sortField'] = [
          [
            'field' => $element['#settings']['sortField'],
            'direction' => $element['#settings']['sortDirection'],
          ],
        ];
      }
      $element['#attached']['drupalSettings']['selectize'][$element['#id']] = json_encode($element['#settings']);

      // If drag_drop plugin is requested, we need to load the sortable plugin.
      if (isset($element['#settings']['plugins']) && in_array('drag_drop', $element['#settings']['plugins'])) {
        $complete_form['#attached']['library'][] = 'core/jquery.ui.sortable';
      }
    }

    // Inject the selectize library and CSS assets.
    $complete_form['#attached']['library'][] = 'selectize/core';
    $complete_form['#attached']['library'][] = 'selectize/drupal';

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function preRenderAjaxForm($element) {
    // Add a reasonable default event handler if none was specified.
    if (isset($element['#ajax']) && !isset($element['#ajax']['event'])) {
      $element['#ajax']['event'] = 'change';
    }
    $element = parent::preRenderAjaxForm($element);
    return $element;
  }

}
