<?php

namespace Drupal\selectize;

use Drupal\Component\Utility\NestedArray;

/**
 * Helper methods for the Selectize elements.
 */
trait SelectizeElementTrait {

  /**
   * Return default settings for Selectize. Pass in values to override defaults.
   *
   * @param array $values
   *   The array of predefined settings.
   *
   * @return array
   *   The default settings array for Selectize.
   */
  public static function settings(array $values = []) {
    $settings = [
      'create' => FALSE,
      'createOnBlur' => FALSE,
      'hideTermId' => FALSE,
      'createFilter' => NULL,
      'delimiter' => ',',
      'delimiter_warning' => FALSE,
      'sortField' => 'text',
      'sortDirection' => 'asc',
      'allowEmptyOption' => FALSE,
      'plugins' => [],
      'highlight' => TRUE,
      'maxItems' => 10,
      'persist' => FALSE,
      'diacritics' => FALSE,
      'closeAfterSelect' => FALSE,
      'placeholder' => '',
    ];

    return array_merge($settings, $values);
  }

  /**
   * Prepares a #type 'selectize' render element for input.html.twig.
   *
   * @param array $element
   *   An associative array containing the properties of the element.
   *   Properties used: #title, #value, #description, #size, #maxlength,
   *   #placeholder, #required, #attributes.
   *
   * @return array
   *   The $element with prepared variables ready for input.html.twig.
   */
  public static function preRenderSelectize(array $element) {
    if (NestedArray::getValue($element, ['#settings', 'delimiter_warning'])) {
      $description = t('Attention: "@delimiter" character used as delimiter!', ['@delimiter' => $element['#settings']['delimiter']]);
      $element['#description'] = $element['#description'] ? $element['#description'] . ' ' . $description : $description;
    }

    return $element;
  }

}
